@@ -698,8 +698,20 @@ should_include_mount (GVfsUDisks2VolumeMonitor  *monitor,
                       GUnixMountEntry           *mount_entry)
 {
   GUnixMountPoint *mount_point;
+  const gchar *options;
   gboolean ret;
 
+  /* g_unix_mount_get_options works only with libmount,
+   * see https://bugzilla.gnome.org/show_bug.cgi?id=668132
+   */
+  options = g_unix_mount_get_options (mount_entry);
+  if (options != NULL)
+    {
+      ret = should_include (g_unix_mount_get_mount_path (mount_entry),
+                            options);
+      goto out;
+    }
+
   /* if mounted at the designated mount point, use that info to decide */
   mount_point = get_mount_point_for_mount (mount_entry);
   if (mount_point != NULL)
@@ -709,9 +721,7 @@ should_include_mount (GVfsUDisks2VolumeMonitor  *monitor,
       goto out;
     }
 
-  /* otherwise, use the mount's info */
-  ret = should_include (g_unix_mount_get_mount_path (mount_entry),
-                        NULL); /* no mount options yet - see bug 668132 */
+  ret = should_include (g_unix_mount_get_mount_path (mount_entry), NULL);
 
  out:
   return ret;
@@ -856,7 +866,7 @@ should_include_volume (GVfsUDisks2VolumeMonitor *monitor,
     }
 
   /* show encrypted volumes... */
-  if (g_strcmp0 (udisks_block_get_id_type (block), "crypto_LUKS") == 0)
+  if (g_strcmp0 (udisks_block_get_id_usage (block), "crypto") == 0)
     {
       UDisksBlock *cleartext_block;
       /* ... unless the volume is unlocked and we don't want to show the cleartext volume */
